"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.gitlab.v1.instance_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetInstanceRequest(google.protobuf.message.Message):
    """Request message for InstanceService.Get"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_ID_FIELD_NUMBER: builtins.int
    instance_id: builtins.str
    """ID of the GitLab instance to return"""
    def __init__(
        self,
        *,
        instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_id", b"instance_id"]) -> None: ...

global___GetInstanceRequest = GetInstanceRequest

@typing.final
class ListInstancesRequest(google.protobuf.message.Message):
    """Request message for InstanceService.List."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list instances in."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListInstancesRequest.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the [ListInstancesRequest.next_page_token]
    returned by the previous list request.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListInstancesRequest = ListInstancesRequest

@typing.final
class ListInstancesResponse(google.protobuf.message.Message):
    """Response message for InstanceService.List."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListInstancesRequest.page_size], use the [next_page_token] as the value
    for the [ListInstancesRequest.page_token] parameter in the next list request. Each subsequent
    list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def instances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.gitlab.v1.instance_pb2.Instance]:
        """List of GitLab instances."""

    def __init__(
        self,
        *,
        instances: collections.abc.Iterable[yandex.cloud.gitlab.v1.instance_pb2.Instance] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instances", b"instances", "next_page_token", b"next_page_token"]) -> None: ...

global___ListInstancesResponse = ListInstancesResponse

@typing.final
class CreateInstanceRequest(google.protobuf.message.Message):
    """Request message for InstanceService.Create."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    ADMIN_LOGIN_FIELD_NUMBER: builtins.int
    ADMIN_EMAIL_FIELD_NUMBER: builtins.int
    DOMAIN_PREFIX_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    BACKUP_RETAIN_PERIOD_DAYS_FIELD_NUMBER: builtins.int
    MAINTENANCE_DELETE_UNTAGGED_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    APPROVAL_RULES_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create instance in."""
    name: builtins.str
    """Name of the instance (must be unique within the folder)."""
    description: builtins.str
    """Description of the instance."""
    resource_preset_id: builtins.str
    """ID of the resource preset for computational resources."""
    disk_size: builtins.int
    """Disk size in bytes."""
    admin_login: builtins.str
    """Admin user login."""
    admin_email: builtins.str
    """Admin user email."""
    domain_prefix: builtins.str
    """Domain prefix for the GitLab instance."""
    subnet_id: builtins.str
    """ID of the subnet where instance will be created."""
    backup_retain_period_days: builtins.int
    """Number of days to retain backups."""
    maintenance_delete_untagged: builtins.bool
    """Whether to delete untagged resources during maintenance."""
    deletion_protection: builtins.bool
    """Whether deletion protection is enabled."""
    approval_rules_id: builtins.str
    """ID of approval rules for the instance."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the instance as `` key:value `` pairs. For example, "env": "prod"."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        resource_preset_id: builtins.str = ...,
        disk_size: builtins.int = ...,
        admin_login: builtins.str = ...,
        admin_email: builtins.str = ...,
        domain_prefix: builtins.str = ...,
        subnet_id: builtins.str = ...,
        backup_retain_period_days: builtins.int = ...,
        maintenance_delete_untagged: builtins.bool = ...,
        deletion_protection: builtins.bool = ...,
        approval_rules_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["admin_email", b"admin_email", "admin_login", b"admin_login", "approval_rules_id", b"approval_rules_id", "backup_retain_period_days", b"backup_retain_period_days", "deletion_protection", b"deletion_protection", "description", b"description", "disk_size", b"disk_size", "domain_prefix", b"domain_prefix", "folder_id", b"folder_id", "labels", b"labels", "maintenance_delete_untagged", b"maintenance_delete_untagged", "name", b"name", "resource_preset_id", b"resource_preset_id", "subnet_id", b"subnet_id"]) -> None: ...

global___CreateInstanceRequest = CreateInstanceRequest

@typing.final
class CreateInstanceMetadata(google.protobuf.message.Message):
    """Metadata message for InstanceService.Create."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_ID_FIELD_NUMBER: builtins.int
    instance_id: builtins.str
    """ID of the GitLab instance being created."""
    def __init__(
        self,
        *,
        instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_id", b"instance_id"]) -> None: ...

global___CreateInstanceMetadata = CreateInstanceMetadata

@typing.final
class UpdateInstanceRequest(google.protobuf.message.Message):
    """Request message for InstanceService.Update."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    INSTANCE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    BACKUP_RETAIN_PERIOD_DAYS_FIELD_NUMBER: builtins.int
    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    MAINTENANCE_DELETE_UNTAGGED_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    APPROVAL_RULES_ID_FIELD_NUMBER: builtins.int
    APPROVAL_RULES_TOKEN_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    instance_id: builtins.str
    """ID of the GitLab instance to update."""
    name: builtins.str
    """Name of the instance (must be unique within the folder)."""
    description: builtins.str
    """Description of the instance."""
    backup_retain_period_days: builtins.int
    """Number of days to retain backups."""
    resource_preset_id: builtins.str
    """ID of the resource preset for computational resources."""
    maintenance_delete_untagged: builtins.bool
    """Whether to delete untagged resources during maintenance."""
    deletion_protection: builtins.bool
    """Whether deletion protection is enabled."""
    approval_rules_id: builtins.str
    """ID of approval rules for the instance."""
    approval_rules_token: builtins.str
    """Token of approval rules for the instance."""
    disk_size: builtins.int
    """Disk size in bytes."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the instance as `` key:value `` pairs. For example, "env": "prod" """

    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the trail are going to be updated."""

    def __init__(
        self,
        *,
        instance_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        backup_retain_period_days: builtins.int = ...,
        resource_preset_id: builtins.str = ...,
        maintenance_delete_untagged: builtins.bool = ...,
        deletion_protection: builtins.bool = ...,
        approval_rules_id: builtins.str = ...,
        approval_rules_token: builtins.str = ...,
        disk_size: builtins.int = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["approval_rules_id", b"approval_rules_id", "approval_rules_token", b"approval_rules_token", "backup_retain_period_days", b"backup_retain_period_days", "deletion_protection", b"deletion_protection", "description", b"description", "disk_size", b"disk_size", "instance_id", b"instance_id", "labels", b"labels", "maintenance_delete_untagged", b"maintenance_delete_untagged", "name", b"name", "resource_preset_id", b"resource_preset_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateInstanceRequest = UpdateInstanceRequest

@typing.final
class UpdateInstanceMetadata(google.protobuf.message.Message):
    """Metadata message for InstanceService.Update."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_ID_FIELD_NUMBER: builtins.int
    instance_id: builtins.str
    """ID of the GitLab instance to update."""
    def __init__(
        self,
        *,
        instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_id", b"instance_id"]) -> None: ...

global___UpdateInstanceMetadata = UpdateInstanceMetadata

@typing.final
class DeleteInstanceRequest(google.protobuf.message.Message):
    """Request message for InstanceService.Delete."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_ID_FIELD_NUMBER: builtins.int
    instance_id: builtins.str
    """ID of the GitLab instance to delete."""
    def __init__(
        self,
        *,
        instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_id", b"instance_id"]) -> None: ...

global___DeleteInstanceRequest = DeleteInstanceRequest

@typing.final
class DeleteInstanceMetadata(google.protobuf.message.Message):
    """Metadata message for InstanceService.Delete."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_ID_FIELD_NUMBER: builtins.int
    instance_id: builtins.str
    """ID of the GitLab instance being deleted."""
    def __init__(
        self,
        *,
        instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_id", b"instance_id"]) -> None: ...

global___DeleteInstanceMetadata = DeleteInstanceMetadata

@typing.final
class StartInstanceRequest(google.protobuf.message.Message):
    """Request message for InstanceService.Start."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_ID_FIELD_NUMBER: builtins.int
    instance_id: builtins.str
    """ID of the GitLab instance to start."""
    def __init__(
        self,
        *,
        instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_id", b"instance_id"]) -> None: ...

global___StartInstanceRequest = StartInstanceRequest

@typing.final
class StartInstanceMetadata(google.protobuf.message.Message):
    """Metadata message for InstanceService.Start."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_ID_FIELD_NUMBER: builtins.int
    instance_id: builtins.str
    """ID of the GitLab instance being started."""
    def __init__(
        self,
        *,
        instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_id", b"instance_id"]) -> None: ...

global___StartInstanceMetadata = StartInstanceMetadata

@typing.final
class StopInstanceRequest(google.protobuf.message.Message):
    """Request message for InstanceService.Stop."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_ID_FIELD_NUMBER: builtins.int
    instance_id: builtins.str
    def __init__(
        self,
        *,
        instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_id", b"instance_id"]) -> None: ...

global___StopInstanceRequest = StopInstanceRequest

@typing.final
class StopInstanceMetadata(google.protobuf.message.Message):
    """Metadata message for InstanceService.Stop."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_ID_FIELD_NUMBER: builtins.int
    instance_id: builtins.str
    """ID of the GitLab instance being stoped."""
    def __init__(
        self,
        *,
        instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instance_id", b"instance_id"]) -> None: ...

global___StopInstanceMetadata = StopInstanceMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Classifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Classifier id"""
    name: builtins.str
    """Classifier name"""
    description: builtins.str
    """Classifier description"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "id", b"id", "name", b"name"]) -> None: ...

global___Classifier = Classifier



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/audittrails/v1/trail_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/audittrails/v1/trail_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.audittrails.v1 import trail_pb2 as yandex_dot_cloud_dot_audittrails_dot_v1_dot_trail__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/audittrails/v1/trail_service.proto\x12\x1byandex.cloud.audittrails.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\'yandex/cloud/audittrails/v1/trail.proto\x1a yandex/cloud/access/access.proto\"7\n\x0fGetTrailRequest\x12\x1e\n\x08trail_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50J\x04\x08\x02\x10\x03\"\x94\x01\n\x11ListTrailsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\"a\n\x12ListTrailsResponse\x12\x32\n\x06trails\x18\x01 \x03(\x0b\x32\".yandex.cloud.audittrails.v1.Trail\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc6\x04\n\x12\x43reateTrailRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x88\x01\n\x06labels\x18\x04 \x03(\x0b\x32;.yandex.cloud.audittrails.v1.CreateTrailRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12I\n\x0b\x64\x65stination\x18\x05 \x01(\x0b\x32..yandex.cloud.audittrails.v1.Trail.DestinationB\x04\xe8\xc7\x31\x01\x12(\n\x12service_account_id\x18\x06 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12=\n\x06\x66ilter\x18\x07 \x01(\x0b\x32).yandex.cloud.audittrails.v1.Trail.FilterB\x02\x18\x01\x12L\n\x10\x66iltering_policy\x18\x08 \x01(\x0b\x32\x32.yandex.cloud.audittrails.v1.Trail.FilteringPolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xec\x04\n\x12UpdateTrailRequest\x12\x1e\n\x08trail_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x88\x01\n\x06labels\x18\x05 \x03(\x0b\x32;.yandex.cloud.audittrails.v1.UpdateTrailRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12\x43\n\x0b\x64\x65stination\x18\x06 \x01(\x0b\x32..yandex.cloud.audittrails.v1.Trail.Destination\x12$\n\x12service_account_id\x18\x07 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12=\n\x06\x66ilter\x18\x08 \x01(\x0b\x32).yandex.cloud.audittrails.v1.Trail.FilterB\x02\x18\x01\x12L\n\x10\x66iltering_policy\x18\t \x01(\x0b\x32\x32.yandex.cloud.audittrails.v1.Trail.FilteringPolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"4\n\x12\x44\x65leteTrailRequest\x12\x1e\n\x08trail_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\'\n\x13\x43reateTrailMetadata\x12\x10\n\x08trail_id\x18\x01 \x01(\t\"\'\n\x13UpdateTrailMetadata\x12\x10\n\x08trail_id\x18\x01 \x01(\t\"\'\n\x13\x44\x65leteTrailMetadata\x12\x10\n\x08trail_id\x18\x01 \x01(\t\"z\n\x1aListTrailOperationsRequest\x12\x1e\n\x08trail_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"m\n\x1bListTrailOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x81\r\n\x0cTrailService\x12\x83\x01\n\x03Get\x12,.yandex.cloud.audittrails.v1.GetTrailRequest\x1a\".yandex.cloud.audittrails.v1.Trail\"*\x82\xd3\xe4\x93\x02$\x12\"/audit-trails/v1/trails/{trail_id}\x12\x88\x01\n\x04List\x12..yandex.cloud.audittrails.v1.ListTrailsRequest\x1a/.yandex.cloud.audittrails.v1.ListTrailsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/audit-trails/v1/trails\x12\xa0\x01\n\x06\x43reate\x12/.yandex.cloud.audittrails.v1.CreateTrailRequest\x1a!.yandex.cloud.operation.Operation\"B\xb2\xd2*\x1c\n\x13\x43reateTrailMetadata\x12\x05Trail\x82\xd3\xe4\x93\x02\x1c\"\x17/audit-trails/v1/trails:\x01*\x12\xab\x01\n\x06Update\x12/.yandex.cloud.audittrails.v1.UpdateTrailRequest\x1a!.yandex.cloud.operation.Operation\"M\xb2\xd2*\x1c\n\x13UpdateTrailMetadata\x12\x05Trail\x82\xd3\xe4\x93\x02\'2\"/audit-trails/v1/trails/{trail_id}:\x01*\x12\xb8\x01\n\x06\x44\x65lete\x12/.yandex.cloud.audittrails.v1.DeleteTrailRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*,\n\x13\x44\x65leteTrailMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02$*\"/audit-trails/v1/trails/{trail_id}\x12\xba\x01\n\x0eListOperations\x12\x37.yandex.cloud.audittrails.v1.ListTrailOperationsRequest\x1a\x38.yandex.cloud.audittrails.v1.ListTrailOperationsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/audit-trails/v1/trails/{trail_id}/operations\x12\xb7\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/audit-trails/v1/trails/{resource_id}:listAccessBindings\x12\xe6\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02<\"7/audit-trails/v1/trails/{resource_id}:setAccessBindings:\x01*\x12\xf3\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x85\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02?\":/audit-trails/v1/trails/{resource_id}:updateAccessBindings:\x01*Bs\n\x1fyandex.cloud.api.audittrails.v1B\x03\x41TSZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/audittrails/v1;audittrailsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.audittrails.v1.trail_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037yandex.cloud.api.audittrails.v1B\003ATSZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/audittrails/v1;audittrails'
  _globals['_GETTRAILREQUEST'].fields_by_name['trail_id']._loaded_options = None
  _globals['_GETTRAILREQUEST'].fields_by_name['trail_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTTRAILSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTTRAILSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTTRAILSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTTRAILSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTTRAILSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTTRAILSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATETRAILREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATETRAILREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATETRAILREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATETRAILREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATETRAILREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATETRAILREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_CREATETRAILREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATETRAILREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_CREATETRAILREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATETRAILREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_CREATETRAILREQUEST'].fields_by_name['destination']._loaded_options = None
  _globals['_CREATETRAILREQUEST'].fields_by_name['destination']._serialized_options = b'\350\3071\001'
  _globals['_CREATETRAILREQUEST'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_CREATETRAILREQUEST'].fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATETRAILREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_CREATETRAILREQUEST'].fields_by_name['filter']._serialized_options = b'\030\001'
  _globals['_UPDATETRAILREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATETRAILREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATETRAILREQUEST'].fields_by_name['trail_id']._loaded_options = None
  _globals['_UPDATETRAILREQUEST'].fields_by_name['trail_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATETRAILREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATETRAILREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_UPDATETRAILREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATETRAILREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_UPDATETRAILREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATETRAILREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _globals['_UPDATETRAILREQUEST'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_UPDATETRAILREQUEST'].fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_UPDATETRAILREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_UPDATETRAILREQUEST'].fields_by_name['filter']._serialized_options = b'\030\001'
  _globals['_DELETETRAILREQUEST'].fields_by_name['trail_id']._loaded_options = None
  _globals['_DELETETRAILREQUEST'].fields_by_name['trail_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTTRAILOPERATIONSREQUEST'].fields_by_name['trail_id']._loaded_options = None
  _globals['_LISTTRAILOPERATIONSREQUEST'].fields_by_name['trail_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTTRAILOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTTRAILOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTTRAILOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTTRAILOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_TRAILSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_TRAILSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002$\022\"/audit-trails/v1/trails/{trail_id}'
  _globals['_TRAILSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_TRAILSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\031\022\027/audit-trails/v1/trails'
  _globals['_TRAILSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_TRAILSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\034\n\023CreateTrailMetadata\022\005Trail\202\323\344\223\002\034\"\027/audit-trails/v1/trails:\001*'
  _globals['_TRAILSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_TRAILSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\034\n\023UpdateTrailMetadata\022\005Trail\202\323\344\223\002\'2\"/audit-trails/v1/trails/{trail_id}:\001*'
  _globals['_TRAILSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_TRAILSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*,\n\023DeleteTrailMetadata\022\025google.protobuf.Empty\202\323\344\223\002$*\"/audit-trails/v1/trails/{trail_id}'
  _globals['_TRAILSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_TRAILSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002/\022-/audit-trails/v1/trails/{trail_id}/operations'
  _globals['_TRAILSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_TRAILSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002:\0228/audit-trails/v1/trails/{resource_id}:listAccessBindings'
  _globals['_TRAILSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_TRAILSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002<\"7/audit-trails/v1/trails/{resource_id}:setAccessBindings:\001*'
  _globals['_TRAILSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_TRAILSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002?\":/audit-trails/v1/trails/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETTRAILREQUEST']._serialized_start=324
  _globals['_GETTRAILREQUEST']._serialized_end=379
  _globals['_LISTTRAILSREQUEST']._serialized_start=382
  _globals['_LISTTRAILSREQUEST']._serialized_end=530
  _globals['_LISTTRAILSRESPONSE']._serialized_start=532
  _globals['_LISTTRAILSRESPONSE']._serialized_end=629
  _globals['_CREATETRAILREQUEST']._serialized_start=632
  _globals['_CREATETRAILREQUEST']._serialized_end=1214
  _globals['_CREATETRAILREQUEST_LABELSENTRY']._serialized_start=1169
  _globals['_CREATETRAILREQUEST_LABELSENTRY']._serialized_end=1214
  _globals['_UPDATETRAILREQUEST']._serialized_start=1217
  _globals['_UPDATETRAILREQUEST']._serialized_end=1837
  _globals['_UPDATETRAILREQUEST_LABELSENTRY']._serialized_start=1169
  _globals['_UPDATETRAILREQUEST_LABELSENTRY']._serialized_end=1214
  _globals['_DELETETRAILREQUEST']._serialized_start=1839
  _globals['_DELETETRAILREQUEST']._serialized_end=1891
  _globals['_CREATETRAILMETADATA']._serialized_start=1893
  _globals['_CREATETRAILMETADATA']._serialized_end=1932
  _globals['_UPDATETRAILMETADATA']._serialized_start=1934
  _globals['_UPDATETRAILMETADATA']._serialized_end=1973
  _globals['_DELETETRAILMETADATA']._serialized_start=1975
  _globals['_DELETETRAILMETADATA']._serialized_end=2014
  _globals['_LISTTRAILOPERATIONSREQUEST']._serialized_start=2016
  _globals['_LISTTRAILOPERATIONSREQUEST']._serialized_end=2138
  _globals['_LISTTRAILOPERATIONSRESPONSE']._serialized_start=2140
  _globals['_LISTTRAILOPERATIONSRESPONSE']._serialized_end=2249
  _globals['_TRAILSERVICE']._serialized_start=2252
  _globals['_TRAILSERVICE']._serialized_end=3917
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.backup.v1.resource_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ResourceServiceStub:
    """A set of methods for managing backup resources: [Compute Cloud instances](/docs/backup/concepts/vm-connection#os)."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.resource_service_pb2.ListResourcesRequest,
        yandex.cloud.backup.v1.resource_service_pb2.ListResourcesResponse,
    ]
    """List resources: Compute Cloud instances."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.resource_service_pb2.GetResourceRequest,
        yandex.cloud.backup.v1.resource_service_pb2.GetResourceResponse,
    ]
    """Get specific Compute Cloud instance."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.resource_service_pb2.DeleteResourceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete specific Compute Cloud instance from Cloud Backup. It does not delete
    instance from Cloud Compute service.
    """

    ListTasks: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.resource_service_pb2.ListTasksRequest,
        yandex.cloud.backup.v1.resource_service_pb2.ListTasksResponse,
    ]
    """List tasks of resources."""

    ListDirectory: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.resource_service_pb2.ListDirectoryRequest,
        yandex.cloud.backup.v1.resource_service_pb2.ListDirectoryResponse,
    ]
    """ListDirectory returns all subdirectories found in requested directory identified
    by the id.
    """

    CreateDirectory: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.resource_service_pb2.CreateDirectoryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """CreateDirectory creates new directory by requested path."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.resource_service_pb2.ListResourceOperationsRequest,
        yandex.cloud.backup.v1.resource_service_pb2.ListResourceOperationsResponse,
    ]
    """ListOperations return all operations in backup service for given instance"""

    GetInstanceRegistrationToken: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.resource_service_pb2.GetInstanceRegistrationTokenRequest,
        yandex.cloud.backup.v1.resource_service_pb2.GetInstanceRegistrationTokenResponse,
    ]
    """Get instance registration token to install backup agent withot SA attached to instance"""

class ResourceServiceAsyncStub:
    """A set of methods for managing backup resources: [Compute Cloud instances](/docs/backup/concepts/vm-connection#os)."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.resource_service_pb2.ListResourcesRequest,
        yandex.cloud.backup.v1.resource_service_pb2.ListResourcesResponse,
    ]
    """List resources: Compute Cloud instances."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.resource_service_pb2.GetResourceRequest,
        yandex.cloud.backup.v1.resource_service_pb2.GetResourceResponse,
    ]
    """Get specific Compute Cloud instance."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.resource_service_pb2.DeleteResourceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete specific Compute Cloud instance from Cloud Backup. It does not delete
    instance from Cloud Compute service.
    """

    ListTasks: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.resource_service_pb2.ListTasksRequest,
        yandex.cloud.backup.v1.resource_service_pb2.ListTasksResponse,
    ]
    """List tasks of resources."""

    ListDirectory: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.resource_service_pb2.ListDirectoryRequest,
        yandex.cloud.backup.v1.resource_service_pb2.ListDirectoryResponse,
    ]
    """ListDirectory returns all subdirectories found in requested directory identified
    by the id.
    """

    CreateDirectory: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.resource_service_pb2.CreateDirectoryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """CreateDirectory creates new directory by requested path."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.resource_service_pb2.ListResourceOperationsRequest,
        yandex.cloud.backup.v1.resource_service_pb2.ListResourceOperationsResponse,
    ]
    """ListOperations return all operations in backup service for given instance"""

    GetInstanceRegistrationToken: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.resource_service_pb2.GetInstanceRegistrationTokenRequest,
        yandex.cloud.backup.v1.resource_service_pb2.GetInstanceRegistrationTokenResponse,
    ]
    """Get instance registration token to install backup agent withot SA attached to instance"""

class ResourceServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing backup resources: [Compute Cloud instances](/docs/backup/concepts/vm-connection#os)."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.backup.v1.resource_service_pb2.ListResourcesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.backup.v1.resource_service_pb2.ListResourcesResponse, collections.abc.Awaitable[yandex.cloud.backup.v1.resource_service_pb2.ListResourcesResponse]]:
        """List resources: Compute Cloud instances."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.backup.v1.resource_service_pb2.GetResourceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.backup.v1.resource_service_pb2.GetResourceResponse, collections.abc.Awaitable[yandex.cloud.backup.v1.resource_service_pb2.GetResourceResponse]]:
        """Get specific Compute Cloud instance."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.backup.v1.resource_service_pb2.DeleteResourceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Delete specific Compute Cloud instance from Cloud Backup. It does not delete
        instance from Cloud Compute service.
        """

    @abc.abstractmethod
    def ListTasks(
        self,
        request: yandex.cloud.backup.v1.resource_service_pb2.ListTasksRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.backup.v1.resource_service_pb2.ListTasksResponse, collections.abc.Awaitable[yandex.cloud.backup.v1.resource_service_pb2.ListTasksResponse]]:
        """List tasks of resources."""

    @abc.abstractmethod
    def ListDirectory(
        self,
        request: yandex.cloud.backup.v1.resource_service_pb2.ListDirectoryRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.backup.v1.resource_service_pb2.ListDirectoryResponse, collections.abc.Awaitable[yandex.cloud.backup.v1.resource_service_pb2.ListDirectoryResponse]]:
        """ListDirectory returns all subdirectories found in requested directory identified
        by the id.
        """

    @abc.abstractmethod
    def CreateDirectory(
        self,
        request: yandex.cloud.backup.v1.resource_service_pb2.CreateDirectoryRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """CreateDirectory creates new directory by requested path."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.backup.v1.resource_service_pb2.ListResourceOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.backup.v1.resource_service_pb2.ListResourceOperationsResponse, collections.abc.Awaitable[yandex.cloud.backup.v1.resource_service_pb2.ListResourceOperationsResponse]]:
        """ListOperations return all operations in backup service for given instance"""

    @abc.abstractmethod
    def GetInstanceRegistrationToken(
        self,
        request: yandex.cloud.backup.v1.resource_service_pb2.GetInstanceRegistrationTokenRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.backup.v1.resource_service_pb2.GetInstanceRegistrationTokenResponse, collections.abc.Awaitable[yandex.cloud.backup.v1.resource_service_pb2.GetInstanceRegistrationTokenResponse]]:
        """Get instance registration token to install backup agent withot SA attached to instance"""

def add_ResourceServiceServicer_to_server(servicer: ResourceServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/smartwebsecurity/v1/waf/waf_profile.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/smartwebsecurity/v1/waf/waf_profile.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.smartwebsecurity.v1 import security_profile_pb2 as yandex_dot_cloud_dot_smartwebsecurity_dot_v1_dot_security__profile__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/smartwebsecurity/v1/waf/waf_profile.proto\x12$yandex.cloud.smartwebsecurity.v1.waf\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x37yandex/cloud/smartwebsecurity/v1/security_profile.proto\"\xad\x15\n\nWafProfile\x12\x10\n\x02id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tfolder_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x16\n\x08\x63loud_id\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x38\n\x04name\x18\x04 \x01(\tB*\xe8\xc7\x31\x01\xf2\xc7\x31\x1a[a-zA-Z0-9][a-zA-Z0-9-_.]*\x8a\xc8\x31\x04\x31-50\x12\x1e\n\x0b\x64\x65scription\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=512\x12\x89\x01\n\x06labels\x18\x06 \x03(\x0b\x32<.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x43\n\x05rules\x18\t \x03(\x0b\x32\x34.yandex.cloud.smartwebsecurity.v1.waf.WafProfileRule\x12V\n\x0f\x65xclusion_rules\x18\n \x03(\x0b\x32=.yandex.cloud.smartwebsecurity.v1.waf.WafProfileExclusionRule\x12U\n\rcore_rule_set\x18\x0b \x01(\x0b\x32<.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.CoreRuleSetH\x00\x12\x65\n\x14\x61nalyze_request_body\x18\x0c \x01(\x0b\x32\x43.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.AnalyzeRequestBodyB\x02\x18\x01\x12U\n\trule_sets\x18\r \x03(\x0b\x32\x42.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.WafProfileRuleSet\x12\x1b\n\x13match_all_rule_sets\x18\x0e \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xa5\x01\n\x0b\x43oreRuleSet\x12*\n\x15inbound_anomaly_score\x18\x01 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x32-10000\x12#\n\x0eparanoia_level\x18\x02 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31,2,3,4\x12\x45\n\x08rule_set\x18\x03 \x01(\x0b\x32-.yandex.cloud.smartwebsecurity.v1.waf.RuleSetB\x04\xe8\xc7\x31\x01\x1a\xf9\x01\n\x12\x41nalyzeRequestBody\x12\x12\n\nis_enabled\x18\x01 \x01(\x08\x12\x30\n\nsize_limit\x18\x02 \x01(\x03\x42\x1c\xfa\xc7\x31\x18\x30,8,16,32,64,128,256,512\x12\x65\n\x11size_limit_action\x18\x03 \x01(\x0e\x32J.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.AnalyzeRequestBody.Action\"6\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\n\n\x06IGNORE\x10\x01\x12\x08\n\x04\x44\x45NY\x10\x02\x1a\x8b\x0b\n\x11WafProfileRuleSet\x12q\n\rcore_rule_set\x18\x01 \x01(\x0b\x32X.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.WafProfileRuleSet.WafProfileCoreRuleSetH\x00\x12m\n\x0bya_rule_set\x18\x02 \x01(\x0b\x32V.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.WafProfileRuleSet.WafProfileYaRuleSetH\x00\x12m\n\x0bml_rule_set\x18\x03 \x01(\x0b\x32V.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.WafProfileRuleSet.WafProfileMlRuleSetH\x00\x12\x1e\n\x08priority\x18\x04 \x01(\x03\x42\x0c\xfa\xc7\x31\x08\x31-999999\x12\x12\n\nis_enabled\x18\x05 \x01(\x08\x12`\n\x06\x61\x63tion\x18\x06 \x01(\x0e\x32P.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.WafProfileRuleSet.RuleSetAction\x1a\xfd\x01\n\tRuleGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x63\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32S.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.WafProfileRuleSet.RuleGroup.Action\x12*\n\x15inbound_anomaly_score\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31-10000\x12\x12\n\nis_enabled\x18\x04 \x01(\x08\"?\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\x08\n\x04\x44\x45NY\x10\x01\x12\x07\n\x03LOG\x10\x02\x12\n\n\x06IGNORE\x10\x03\x1a\xaf\x01\n\x15WafProfileCoreRuleSet\x12\x45\n\x08rule_set\x18\x01 \x01(\x0b\x32-.yandex.cloud.smartwebsecurity.v1.waf.RuleSetB\x04\xe8\xc7\x31\x01\x12*\n\x15inbound_anomaly_score\x18\x02 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x32-10000\x12#\n\x0eparanoia_level\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31,2,3,4\x1a\xbf\x01\n\x13WafProfileYaRuleSet\x12\x45\n\x08rule_set\x18\x01 \x01(\x0b\x32-.yandex.cloud.smartwebsecurity.v1.waf.RuleSetB\x04\xe8\xc7\x31\x01\x12\x61\n\x0brule_groups\x18\x02 \x03(\x0b\x32L.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.WafProfileRuleSet.RuleGroup\x1a\xbf\x01\n\x13WafProfileMlRuleSet\x12\x45\n\x08rule_set\x18\x01 \x01(\x0b\x32-.yandex.cloud.smartwebsecurity.v1.waf.RuleSetB\x04\xe8\xc7\x31\x01\x12\x61\n\x0brule_groups\x18\x02 \x03(\x0b\x32L.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.WafProfileRuleSet.RuleGroup\"G\n\rRuleSetAction\x12\x1f\n\x1bRULE_SET_ACTION_UNSPECIFIED\x10\x00\x12\x08\n\x04\x44\x45NY\x10\x01\x12\x0b\n\x07\x43\x41PTCHA\x10\x02\x42\x10\n\x08rule_set\x12\x04\xc0\xc1\x31\x01\x42\x10\n\x08rule_set\x12\x04\xc0\xc1\x31\x01J\x04\x08\x08\x10\t\"P\n\x0eWafProfileRule\x12\x15\n\x07rule_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x12\n\nis_enabled\x18\x02 \x01(\x08\x12\x13\n\x0bis_blocking\x18\x03 \x01(\x08\"\xc3\x02\n\x17WafProfileExclusionRule\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1e\n\x0b\x64\x65scription\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=512\x12>\n\tcondition\x18\x03 \x01(\x0b\x32+.yandex.cloud.smartwebsecurity.v1.Condition\x12g\n\rexclude_rules\x18\x04 \x01(\x0b\x32J.yandex.cloud.smartwebsecurity.v1.waf.WafProfileExclusionRule.ExcludeRulesB\x04\xe8\xc7\x31\x01\x12\x14\n\x0clog_excluded\x18\x05 \x01(\x08\x1a\x35\n\x0c\x45xcludeRules\x12\x13\n\x0b\x65xclude_all\x18\x01 \x01(\x08\x12\x10\n\x08rule_ids\x18\x02 \x03(\t\"\xd1\x01\n\x07RuleSet\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x15\n\x07version\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12G\n\x04type\x18\x03 \x01(\x0e\x32\x39.yandex.cloud.smartwebsecurity.v1.waf.RuleSet.RuleSetType\x12\n\n\x02id\x18\x04 \x01(\t\"F\n\x0bRuleSetType\x12\x1d\n\x19RULE_SET_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x43ORE\x10\x01\x12\x06\n\x02YA\x10\x02\x12\x06\n\x02ML\x10\x03\x42\x85\x01\n(yandex.cloud.api.smartwebsecurity.v1.wafZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1/waf;smartwebsecurityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.smartwebsecurity.v1.wafZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1/waf;smartwebsecurity'
  _globals['_WAFPROFILE_LABELSENTRY']._loaded_options = None
  _globals['_WAFPROFILE_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_WAFPROFILE_CORERULESET'].fields_by_name['inbound_anomaly_score']._loaded_options = None
  _globals['_WAFPROFILE_CORERULESET'].fields_by_name['inbound_anomaly_score']._serialized_options = b'\372\3071\0072-10000'
  _globals['_WAFPROFILE_CORERULESET'].fields_by_name['paranoia_level']._loaded_options = None
  _globals['_WAFPROFILE_CORERULESET'].fields_by_name['paranoia_level']._serialized_options = b'\372\3071\0071,2,3,4'
  _globals['_WAFPROFILE_CORERULESET'].fields_by_name['rule_set']._loaded_options = None
  _globals['_WAFPROFILE_CORERULESET'].fields_by_name['rule_set']._serialized_options = b'\350\3071\001'
  _globals['_WAFPROFILE_ANALYZEREQUESTBODY'].fields_by_name['size_limit']._loaded_options = None
  _globals['_WAFPROFILE_ANALYZEREQUESTBODY'].fields_by_name['size_limit']._serialized_options = b'\372\3071\0300,8,16,32,64,128,256,512'
  _globals['_WAFPROFILE_WAFPROFILERULESET_RULEGROUP'].fields_by_name['inbound_anomaly_score']._loaded_options = None
  _globals['_WAFPROFILE_WAFPROFILERULESET_RULEGROUP'].fields_by_name['inbound_anomaly_score']._serialized_options = b'\372\3071\0071-10000'
  _globals['_WAFPROFILE_WAFPROFILERULESET_WAFPROFILECORERULESET'].fields_by_name['rule_set']._loaded_options = None
  _globals['_WAFPROFILE_WAFPROFILERULESET_WAFPROFILECORERULESET'].fields_by_name['rule_set']._serialized_options = b'\350\3071\001'
  _globals['_WAFPROFILE_WAFPROFILERULESET_WAFPROFILECORERULESET'].fields_by_name['inbound_anomaly_score']._loaded_options = None
  _globals['_WAFPROFILE_WAFPROFILERULESET_WAFPROFILECORERULESET'].fields_by_name['inbound_anomaly_score']._serialized_options = b'\372\3071\0072-10000'
  _globals['_WAFPROFILE_WAFPROFILERULESET_WAFPROFILECORERULESET'].fields_by_name['paranoia_level']._loaded_options = None
  _globals['_WAFPROFILE_WAFPROFILERULESET_WAFPROFILECORERULESET'].fields_by_name['paranoia_level']._serialized_options = b'\372\3071\0071,2,3,4'
  _globals['_WAFPROFILE_WAFPROFILERULESET_WAFPROFILEYARULESET'].fields_by_name['rule_set']._loaded_options = None
  _globals['_WAFPROFILE_WAFPROFILERULESET_WAFPROFILEYARULESET'].fields_by_name['rule_set']._serialized_options = b'\350\3071\001'
  _globals['_WAFPROFILE_WAFPROFILERULESET_WAFPROFILEMLRULESET'].fields_by_name['rule_set']._loaded_options = None
  _globals['_WAFPROFILE_WAFPROFILERULESET_WAFPROFILEMLRULESET'].fields_by_name['rule_set']._serialized_options = b'\350\3071\001'
  _globals['_WAFPROFILE_WAFPROFILERULESET'].oneofs_by_name['rule_set']._loaded_options = None
  _globals['_WAFPROFILE_WAFPROFILERULESET'].oneofs_by_name['rule_set']._serialized_options = b'\300\3011\001'
  _globals['_WAFPROFILE_WAFPROFILERULESET'].fields_by_name['priority']._loaded_options = None
  _globals['_WAFPROFILE_WAFPROFILERULESET'].fields_by_name['priority']._serialized_options = b'\372\3071\0101-999999'
  _globals['_WAFPROFILE'].oneofs_by_name['rule_set']._loaded_options = None
  _globals['_WAFPROFILE'].oneofs_by_name['rule_set']._serialized_options = b'\300\3011\001'
  _globals['_WAFPROFILE'].fields_by_name['id']._loaded_options = None
  _globals['_WAFPROFILE'].fields_by_name['id']._serialized_options = b'\350\3071\001'
  _globals['_WAFPROFILE'].fields_by_name['folder_id']._loaded_options = None
  _globals['_WAFPROFILE'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_WAFPROFILE'].fields_by_name['cloud_id']._loaded_options = None
  _globals['_WAFPROFILE'].fields_by_name['cloud_id']._serialized_options = b'\350\3071\001'
  _globals['_WAFPROFILE'].fields_by_name['name']._loaded_options = None
  _globals['_WAFPROFILE'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\032[a-zA-Z0-9][a-zA-Z0-9-_.]*\212\3101\0041-50'
  _globals['_WAFPROFILE'].fields_by_name['description']._loaded_options = None
  _globals['_WAFPROFILE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=512'
  _globals['_WAFPROFILE'].fields_by_name['labels']._loaded_options = None
  _globals['_WAFPROFILE'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_WAFPROFILE'].fields_by_name['analyze_request_body']._loaded_options = None
  _globals['_WAFPROFILE'].fields_by_name['analyze_request_body']._serialized_options = b'\030\001'
  _globals['_WAFPROFILERULE'].fields_by_name['rule_id']._loaded_options = None
  _globals['_WAFPROFILERULE'].fields_by_name['rule_id']._serialized_options = b'\350\3071\001'
  _globals['_WAFPROFILEEXCLUSIONRULE'].fields_by_name['name']._loaded_options = None
  _globals['_WAFPROFILEEXCLUSIONRULE'].fields_by_name['name']._serialized_options = b'\350\3071\001'
  _globals['_WAFPROFILEEXCLUSIONRULE'].fields_by_name['description']._loaded_options = None
  _globals['_WAFPROFILEEXCLUSIONRULE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=512'
  _globals['_WAFPROFILEEXCLUSIONRULE'].fields_by_name['exclude_rules']._loaded_options = None
  _globals['_WAFPROFILEEXCLUSIONRULE'].fields_by_name['exclude_rules']._serialized_options = b'\350\3071\001'
  _globals['_RULESET'].fields_by_name['name']._loaded_options = None
  _globals['_RULESET'].fields_by_name['name']._serialized_options = b'\350\3071\001'
  _globals['_RULESET'].fields_by_name['version']._loaded_options = None
  _globals['_RULESET'].fields_by_name['version']._serialized_options = b'\350\3071\001'
  _globals['_WAFPROFILE']._serialized_start=218
  _globals['_WAFPROFILE']._serialized_end=2951
  _globals['_WAFPROFILE_LABELSENTRY']._serialized_start=1040
  _globals['_WAFPROFILE_LABELSENTRY']._serialized_end=1085
  _globals['_WAFPROFILE_CORERULESET']._serialized_start=1088
  _globals['_WAFPROFILE_CORERULESET']._serialized_end=1253
  _globals['_WAFPROFILE_ANALYZEREQUESTBODY']._serialized_start=1256
  _globals['_WAFPROFILE_ANALYZEREQUESTBODY']._serialized_end=1505
  _globals['_WAFPROFILE_ANALYZEREQUESTBODY_ACTION']._serialized_start=1451
  _globals['_WAFPROFILE_ANALYZEREQUESTBODY_ACTION']._serialized_end=1505
  _globals['_WAFPROFILE_WAFPROFILERULESET']._serialized_start=1508
  _globals['_WAFPROFILE_WAFPROFILERULESET']._serialized_end=2927
  _globals['_WAFPROFILE_WAFPROFILERULESET_RULEGROUP']._serialized_start=2017
  _globals['_WAFPROFILE_WAFPROFILERULESET_RULEGROUP']._serialized_end=2270
  _globals['_WAFPROFILE_WAFPROFILERULESET_RULEGROUP_ACTION']._serialized_start=2207
  _globals['_WAFPROFILE_WAFPROFILERULESET_RULEGROUP_ACTION']._serialized_end=2270
  _globals['_WAFPROFILE_WAFPROFILERULESET_WAFPROFILECORERULESET']._serialized_start=2273
  _globals['_WAFPROFILE_WAFPROFILERULESET_WAFPROFILECORERULESET']._serialized_end=2448
  _globals['_WAFPROFILE_WAFPROFILERULESET_WAFPROFILEYARULESET']._serialized_start=2451
  _globals['_WAFPROFILE_WAFPROFILERULESET_WAFPROFILEYARULESET']._serialized_end=2642
  _globals['_WAFPROFILE_WAFPROFILERULESET_WAFPROFILEMLRULESET']._serialized_start=2645
  _globals['_WAFPROFILE_WAFPROFILERULESET_WAFPROFILEMLRULESET']._serialized_end=2836
  _globals['_WAFPROFILE_WAFPROFILERULESET_RULESETACTION']._serialized_start=2838
  _globals['_WAFPROFILE_WAFPROFILERULESET_RULESETACTION']._serialized_end=2909
  _globals['_WAFPROFILERULE']._serialized_start=2953
  _globals['_WAFPROFILERULE']._serialized_end=3033
  _globals['_WAFPROFILEEXCLUSIONRULE']._serialized_start=3036
  _globals['_WAFPROFILEEXCLUSIONRULE']._serialized_end=3359
  _globals['_WAFPROFILEEXCLUSIONRULE_EXCLUDERULES']._serialized_start=3306
  _globals['_WAFPROFILEEXCLUSIONRULE_EXCLUDERULES']._serialized_end=3359
  _globals['_RULESET']._serialized_start=3362
  _globals['_RULESET']._serialized_end=3571
  _globals['_RULESET_RULESETTYPE']._serialized_start=3501
  _globals['_RULESET_RULESETTYPE']._serialized_end=3571
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/clickhouse/v1/user.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/clickhouse/v1/user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/mdb/clickhouse/v1/user.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xbf\x02\n\x04User\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x18\n\ncluster_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12?\n\x0bpermissions\x18\x03 \x03(\x0b\x32*.yandex.cloud.mdb.clickhouse.v1.Permission\x12>\n\x08settings\x18\x04 \x01(\x0b\x32,.yandex.cloud.mdb.clickhouse.v1.UserSettings\x12\x39\n\x06quotas\x18\x05 \x03(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.UserQuota\x12M\n\x12\x63onnection_manager\x18\x06 \x01(\x0b\x32\x31.yandex.cloud.mdb.clickhouse.v1.ConnectionManager\")\n\nPermission\x12\x15\n\rdatabase_name\x18\x01 \x01(\tJ\x04\x08\x02\x10\x03\"\xb1y\n\x0cUserSettings\x12\x36\n\x08readonly\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03\x30-2\x12-\n\tallow_ddl\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x1d\x61llow_introspection_functions\x18` \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x0f\x63onnect_timeout\x18\' \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\x1d\x63onnect_timeout_with_failover\x18\x61 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x34\n\x0freceive_timeout\x18( \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0csend_timeout\x18) \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12=\n\x17idle_connection_timeout\x18\x8e\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12L\n\'timeout_before_checking_execution_speed\x18\x62 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\rinsert_quorum\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12:\n\x15insert_quorum_timeout\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x16insert_quorum_parallel\x18\x63 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x1dselect_sequential_consistency\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12O\n!replication_alter_partitions_sync\x18* \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03\x30-2\x12N\n)max_replica_delay_for_distributed_queries\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12V\n2fallback_to_stale_replicas_for_distributed_queries\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x65\n\x18\x64istributed_product_mode\x18+ \x01(\x0e\x32\x43.yandex.cloud.mdb.clickhouse.v1.UserSettings.DistributedProductMode\x12L\n(distributed_aggregation_memory_efficient\x18H \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x1c\x64istributed_ddl_task_timeout\x18I \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12k\n\x1b\x64istributed_ddl_output_mode\x18\xa9\x01 \x01(\x0e\x32\x45.yandex.cloud.mdb.clickhouse.v1.UserSettings.DistributedDdlOutputMode\x12;\n\x17skip_unavailable_shards\x18Q \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x13use_hedged_requests\x18\x8d\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x1chedged_connection_timeout_ms\x18\x8f\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12S\n\x0eload_balancing\x18\x90\x01 \x01(\x0e\x32:.yandex.cloud.mdb.clickhouse.v1.UserSettings.LoadBalancing\x12=\n\x18prefer_localhost_replica\x18\x91\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x13\x63ompile_expressions\x18. \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12M\n\x1fmin_count_to_compile_expression\x18/ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12<\n\x0emax_block_size\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=1\x12H\n\x1amin_insert_block_size_rows\x18\x30 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12I\n\x1bmin_insert_block_size_bytes\x18\x31 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x43\n\x15max_insert_block_size\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=1\x12M\n\x1fmax_partitions_per_insert_block\x18\x66 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12H\n\x1amin_bytes_to_use_direct_io\x18\x32 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12:\n\x16use_uncompressed_cache\x18\x33 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12N\n merge_tree_max_rows_to_use_cache\x18\x34 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=1\x12O\n!merge_tree_max_bytes_to_use_cache\x18\x35 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=1\x12U\n\'merge_tree_min_rows_for_concurrent_read\x18\x36 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=1\x12V\n(merge_tree_min_bytes_for_concurrent_read\x18\x37 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=1\x12P\n\"max_bytes_before_external_group_by\x18J \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12L\n\x1emax_bytes_before_external_sort\x18K \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12J\n\x1cgroup_by_two_level_threshold\x18L \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12P\n\"group_by_two_level_threshold_bytes\x18M \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12V\n2deduplicate_blocks_in_dependent_materialized_views\x18\x65 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12m\n\x1clocal_filesystem_read_method\x18\x81\x01 \x01(\x0e\x32\x46.yandex.cloud.mdb.clickhouse.v1.UserSettings.LocalFilesystemReadMethod\x12o\n\x1dremote_filesystem_read_method\x18\x87\x01 \x01(\x0e\x32G.yandex.cloud.mdb.clickhouse.v1.UserSettings.RemoteFilesystemReadMethod\x12\x36\n\x08priority\x18\x38 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x39\n\x0bmax_threads\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x41\n\x12max_insert_threads\x18\x8c\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12>\n\x10max_memory_usage\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12G\n\x19max_memory_usage_for_user\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12R\n#memory_overcommit_ratio_denominator\x18\x88\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12[\n,memory_overcommit_ratio_denominator_for_user\x18\x89\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\\\n-memory_usage_overcommit_max_wait_microseconds\x18\x8a\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x43\n\x15max_network_bandwidth\x18\x39 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12L\n\x1emax_network_bandwidth_for_user\x18: \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12X\n)max_temporary_data_on_disk_size_for_query\x18\x85\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12W\n(max_temporary_data_on_disk_size_for_user\x18\x84\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x44\n\x1fmax_concurrent_queries_for_user\x18g \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x13\x66orce_index_by_date\x18; \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x11\x66orce_primary_key\x18< \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12>\n\x10max_rows_to_read\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12?\n\x11max_bytes_to_read\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12U\n\x12read_overflow_mode\x18\x0f \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12\x42\n\x14max_rows_to_group_by\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12`\n\x16group_by_overflow_mode\x18\x11 \x01(\x0e\x32@.yandex.cloud.mdb.clickhouse.v1.UserSettings.GroupByOverflowMode\x12>\n\x10max_rows_to_sort\x18\x12 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12?\n\x11max_bytes_to_sort\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12U\n\x12sort_overflow_mode\x18\x14 \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12=\n\x0fmax_result_rows\x18\x15 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12>\n\x10max_result_bytes\x18\x16 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12W\n\x14result_overflow_mode\x18\x17 \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12\x42\n\x14max_rows_in_distinct\x18\x18 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x43\n\x15max_bytes_in_distinct\x18\x19 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12Y\n\x16\x64istinct_overflow_mode\x18\x1a \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12\x42\n\x14max_rows_to_transfer\x18\x1b \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x43\n\x15max_bytes_to_transfer\x18\x1c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12Y\n\x16transfer_overflow_mode\x18\x1d \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12@\n\x12max_execution_time\x18\x1e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12X\n\x15timeout_overflow_mode\x18\x1f \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12=\n\x0fmax_rows_in_set\x18W \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12>\n\x10max_bytes_in_set\x18X \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12T\n\x11set_overflow_mode\x18Y \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12>\n\x10max_rows_in_join\x18Z \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12?\n\x11max_bytes_in_join\x18[ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12U\n\x12join_overflow_mode\x18\\ \x01(\x0e\x32\x39.yandex.cloud.mdb.clickhouse.v1.UserSettings.OverflowMode\x12\x41\n\x13max_columns_to_read\x18  \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x43\n\x15max_temporary_columns\x18! \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12M\n\x1fmax_temporary_non_const_columns\x18\" \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12<\n\x0emax_query_size\x18# \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=1\x12;\n\rmax_ast_depth\x18$ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=1\x12>\n\x10max_ast_elements\x18% \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=1\x12G\n\x19max_expanded_ast_elements\x18& \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=1\x12?\n\x10max_parser_depth\x18\x86\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x41\n\x13min_execution_speed\x18T \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12G\n\x19min_execution_speed_bytes\x18U \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12M\n)input_format_values_interpret_expressions\x18= \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12L\n(input_format_defaults_for_omitted_fields\x18> \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12@\n\x1cinput_format_null_as_default\x18j \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x46\n\"input_format_with_names_use_header\x18l \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12p\n\'output_format_json_quote_64bit_integers\x18? \x01(\x0b\x32\x1a.google.protobuf.BoolValueR#outputFormatJsonQuote_64bitIntegers\x12\x46\n\"output_format_json_quote_denormals\x18@ \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12`\n\x16\x64\x61te_time_input_format\x18k \x01(\x0e\x32@.yandex.cloud.mdb.clickhouse.v1.UserSettings.DateTimeInputFormat\x12\x62\n\x17\x64\x61te_time_output_format\x18m \x01(\x0e\x32\x41.yandex.cloud.mdb.clickhouse.v1.UserSettings.DateTimeOutputFormat\x12J\n&low_cardinality_allow_in_native_format\x18N \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12M\n)empty_result_for_aggregation_by_empty_set\x18O \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x15\n\rformat_regexp\x18r \x01(\t\x12j\n\x1b\x66ormat_regexp_escaping_rule\x18s \x01(\x0e\x32\x45.yandex.cloud.mdb.clickhouse.v1.UserSettings.FormatRegexpEscapingRule\x12@\n\x1c\x66ormat_regexp_skip_unmatched\x18t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x1dinput_format_parallel_parsing\x18\x7f \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x44\n\x1finput_format_import_nested_json\x18\x80\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12(\n\x1f\x66ormat_avro_schema_registry_url\x18\x94\x01 \x01(\t\x12?\n\x1a\x64\x61ta_type_default_nullable\x18\x95\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\x17http_connection_timeout\x18\x41 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14http_receive_timeout\x18\x42 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11http_send_timeout\x18\x43 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x17\x65nable_http_compression\x18\x44 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x1dsend_progress_in_http_headers\x18\x45 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x43\n\x1ehttp_headers_progress_interval\x18\x46 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x14\x61\x64\x64_http_cors_header\x18G \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12P\n,cancel_http_readonly_queries_on_client_close\x18o \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12;\n\x16max_http_get_redirects\x18p \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x18http_max_field_name_size\x18\x96\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12?\n\x19http_max_field_value_size\x18\x97\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12J\n\nquota_mode\x18P \x01(\x0e\x32\x36.yandex.cloud.mdb.clickhouse.v1.UserSettings.QuotaMode\x12\x30\n\x0c\x61sync_insert\x18u \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x15wait_for_async_insert\x18w \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x1dwait_for_async_insert_timeout\x18x \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12?\n\x1a\x61sync_insert_max_data_size\x18y \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19\x61sync_insert_busy_timeout\x18z \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12K\n&async_insert_use_adaptive_busy_timeout\x18\x98\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x11log_query_threads\x18\x8b\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x0flog_query_views\x18\x92\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12>\n\x17log_queries_probability\x18\x99\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12<\n\x17log_processors_profiles\x18\x9a\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x0fuse_query_cache\x18\x9b\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x1d\x65nable_reads_from_query_cache\x18\x9c\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x1c\x65nable_writes_to_query_cache\x18\x9d\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12I\n\x1aquery_cache_min_query_runs\x18\x9e\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x44\n\x1equery_cache_min_query_duration\x18\x9f\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x35\n\x0fquery_cache_ttl\x18\xa0\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12=\n\x17query_cache_max_entries\x18\xa1\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x43\n\x1dquery_cache_max_size_in_bytes\x18\xa2\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x18\n\x0fquery_cache_tag\x18\xa3\x01 \x01(\t\x12\x44\n\x1fquery_cache_share_between_users\x18\xa4\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x90\x01\n.query_cache_nondeterministic_function_handling\x18\xa5\x01 \x01(\x0e\x32W.yandex.cloud.mdb.clickhouse.v1.UserSettings.QueryCacheNondeterministicFunctionHandling\x12v\n!query_cache_system_table_handling\x18\xa8\x01 \x01(\x0e\x32J.yandex.cloud.mdb.clickhouse.v1.UserSettings.QueryCacheSystemTableHandling\x12o\n\x1d\x63ount_distinct_implementation\x18V \x01(\x0e\x32H.yandex.cloud.mdb.clickhouse.v1.UserSettings.CountDistinctImplementation\x12\x42\n\x1ejoined_subquery_requires_alias\x18] \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0ejoin_use_nulls\x18^ \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x11transform_null_in\x18_ \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12:\n\x16insert_null_as_default\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12R\n\x0ejoin_algorithm\x18h \x03(\x0e\x32:.yandex.cloud.mdb.clickhouse.v1.UserSettings.JoinAlgorithm\x12\x46\n\"any_join_distinct_right_table_keys\x18i \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12J\n&allow_suspicious_low_cardinality_types\x18n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0e\x66latten_nested\x18q \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x14memory_profiler_step\x18| \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12Q\n\"memory_profiler_sample_probability\x18} \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x07\xfa\xc7\x31\x03\x30-1\x12?\n\x11max_final_threads\x18~ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x43\n\x14max_read_buffer_size\x18\x82\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=1\x12H\n\x19insert_keeper_max_retries\x18\x83\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12P\n+do_not_merge_across_partitions_select_final\x18\x93\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12X\n3ignore_materialized_views_with_dropped_target_table\x18\xa6\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x0f\x65nable_analyzer\x18\xa7\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12=\n\x18s3_use_adaptive_timeouts\x18\xaa\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x05\x66inal\x18\xab\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12/\n\x07\x63ompile\x18, \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x02\x18\x01\x12=\n\x14min_count_to_compile\x18- \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x02\x18\x01\x12=\n\x14\x61sync_insert_threads\x18v \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x02\x18\x01\x12\x43\n\x1a\x61sync_insert_stale_timeout\x18{ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x02\x18\x01\"\xd2\x01\n\x16\x44istributedProductMode\x12(\n$DISTRIBUTED_PRODUCT_MODE_UNSPECIFIED\x10\x00\x12!\n\x1d\x44ISTRIBUTED_PRODUCT_MODE_DENY\x10\x01\x12\"\n\x1e\x44ISTRIBUTED_PRODUCT_MODE_LOCAL\x10\x02\x12#\n\x1f\x44ISTRIBUTED_PRODUCT_MODE_GLOBAL\x10\x03\x12\"\n\x1e\x44ISTRIBUTED_PRODUCT_MODE_ALLOW\x10\x04\"\xa2\x03\n\x18\x44istributedDdlOutputMode\x12+\n\'DISTRIBUTED_DDL_OUTPUT_MODE_UNSPECIFIED\x10\x00\x12%\n!DISTRIBUTED_DDL_OUTPUT_MODE_THROW\x10\x01\x12$\n DISTRIBUTED_DDL_OUTPUT_MODE_NONE\x10\x02\x12\x36\n2DISTRIBUTED_DDL_OUTPUT_MODE_NULL_STATUS_ON_TIMEOUT\x10\x03\x12+\n\'DISTRIBUTED_DDL_OUTPUT_MODE_NEVER_THROW\x10\x04\x12\x30\n,DISTRIBUTED_DDL_OUTPUT_MODE_NONE_ONLY_ACTIVE\x10\x05\x12\x42\n>DISTRIBUTED_DDL_OUTPUT_MODE_NULL_STATUS_ON_TIMEOUT_ONLY_ACTIVE\x10\x06\x12\x31\n-DISTRIBUTED_DDL_OUTPUT_MODE_THROW_ONLY_ACTIVE\x10\x07\"\xd0\x01\n\rLoadBalancing\x12\x1e\n\x1aLOAD_BALANCING_UNSPECIFIED\x10\x00\x12\x19\n\x15LOAD_BALANCING_RANDOM\x10\x01\x12#\n\x1fLOAD_BALANCING_NEAREST_HOSTNAME\x10\x02\x12\x1b\n\x17LOAD_BALANCING_IN_ORDER\x10\x03\x12\"\n\x1eLOAD_BALANCING_FIRST_OR_RANDOM\x10\x04\x12\x1e\n\x1aLOAD_BALANCING_ROUND_ROBIN\x10\x05\"\x9d\x02\n\x19LocalFilesystemReadMethod\x12,\n(LOCAL_FILESYSTEM_READ_METHOD_UNSPECIFIED\x10\x00\x12%\n!LOCAL_FILESYSTEM_READ_METHOD_READ\x10\x01\x12\x31\n-LOCAL_FILESYSTEM_READ_METHOD_PREAD_THREADPOOL\x10\x02\x12&\n\"LOCAL_FILESYSTEM_READ_METHOD_PREAD\x10\x03\x12%\n!LOCAL_FILESYSTEM_READ_METHOD_NMAP\x10\x04\x12)\n%LOCAL_FILESYSTEM_READ_METHOD_IO_URING\x10\x05\"\xa1\x01\n\x1aRemoteFilesystemReadMethod\x12-\n)REMOTE_FILESYSTEM_READ_METHOD_UNSPECIFIED\x10\x00\x12&\n\"REMOTE_FILESYSTEM_READ_METHOD_READ\x10\x01\x12,\n(REMOTE_FILESYSTEM_READ_METHOD_THREADPOOL\x10\x02\"_\n\x0cOverflowMode\x12\x1d\n\x19OVERFLOW_MODE_UNSPECIFIED\x10\x00\x12\x17\n\x13OVERFLOW_MODE_THROW\x10\x01\x12\x17\n\x13OVERFLOW_MODE_BREAK\x10\x02\"\xa1\x01\n\x13GroupByOverflowMode\x12&\n\"GROUP_BY_OVERFLOW_MODE_UNSPECIFIED\x10\x00\x12 \n\x1cGROUP_BY_OVERFLOW_MODE_THROW\x10\x01\x12 \n\x1cGROUP_BY_OVERFLOW_MODE_BREAK\x10\x02\x12\x1e\n\x1aGROUP_BY_OVERFLOW_MODE_ANY\x10\x03\"\xb2\x01\n\x13\x44\x61teTimeInputFormat\x12&\n\"DATE_TIME_INPUT_FORMAT_UNSPECIFIED\x10\x00\x12&\n\"DATE_TIME_INPUT_FORMAT_BEST_EFFORT\x10\x01\x12 \n\x1c\x44\x41TE_TIME_INPUT_FORMAT_BASIC\x10\x02\x12)\n%DATE_TIME_INPUT_FORMAT_BEST_EFFORT_US\x10\x03\"\xb0\x01\n\x14\x44\x61teTimeOutputFormat\x12\'\n#DATE_TIME_OUTPUT_FORMAT_UNSPECIFIED\x10\x00\x12\"\n\x1e\x44\x41TE_TIME_OUTPUT_FORMAT_SIMPLE\x10\x01\x12\x1f\n\x1b\x44\x41TE_TIME_OUTPUT_FORMAT_ISO\x10\x02\x12*\n&DATE_TIME_OUTPUT_FORMAT_UNIX_TIMESTAMP\x10\x03\"\xad\x02\n\x18\x46ormatRegexpEscapingRule\x12+\n\'FORMAT_REGEXP_ESCAPING_RULE_UNSPECIFIED\x10\x00\x12\'\n#FORMAT_REGEXP_ESCAPING_RULE_ESCAPED\x10\x01\x12&\n\"FORMAT_REGEXP_ESCAPING_RULE_QUOTED\x10\x02\x12#\n\x1f\x46ORMAT_REGEXP_ESCAPING_RULE_CSV\x10\x03\x12$\n FORMAT_REGEXP_ESCAPING_RULE_JSON\x10\x04\x12#\n\x1f\x46ORMAT_REGEXP_ESCAPING_RULE_XML\x10\x05\x12#\n\x1f\x46ORMAT_REGEXP_ESCAPING_RULE_RAW\x10\x06\"q\n\tQuotaMode\x12\x1a\n\x16QUOTA_MODE_UNSPECIFIED\x10\x00\x12\x16\n\x12QUOTA_MODE_DEFAULT\x10\x01\x12\x14\n\x10QUOTA_MODE_KEYED\x10\x02\x12\x1a\n\x16QUOTA_MODE_KEYED_BY_IP\x10\x03\"\x9a\x02\n*QueryCacheNondeterministicFunctionHandling\x12>\n:QUERY_CACHE_NONDETERMINISTIC_FUNCTION_HANDLING_UNSPECIFIED\x10\x00\x12\x38\n4QUERY_CACHE_NONDETERMINISTIC_FUNCTION_HANDLING_THROW\x10\x01\x12\x37\n3QUERY_CACHE_NONDETERMINISTIC_FUNCTION_HANDLING_SAVE\x10\x02\x12\x39\n5QUERY_CACHE_NONDETERMINISTIC_FUNCTION_HANDLING_IGNORE\x10\x03\"\xd9\x01\n\x1dQueryCacheSystemTableHandling\x12\x31\n-QUERY_CACHE_SYSTEM_TABLE_HANDLING_UNSPECIFIED\x10\x00\x12+\n\'QUERY_CACHE_SYSTEM_TABLE_HANDLING_THROW\x10\x01\x12*\n&QUERY_CACHE_SYSTEM_TABLE_HANDLING_SAVE\x10\x02\x12,\n(QUERY_CACHE_SYSTEM_TABLE_HANDLING_IGNORE\x10\x03\"\xb6\x02\n\x1b\x43ountDistinctImplementation\x12-\n)COUNT_DISTINCT_IMPLEMENTATION_UNSPECIFIED\x10\x00\x12&\n\"COUNT_DISTINCT_IMPLEMENTATION_UNIQ\x10\x01\x12/\n+COUNT_DISTINCT_IMPLEMENTATION_UNIQ_COMBINED\x10\x02\x12\x32\n.COUNT_DISTINCT_IMPLEMENTATION_UNIQ_COMBINED_64\x10\x03\x12-\n)COUNT_DISTINCT_IMPLEMENTATION_UNIQ_HLL_12\x10\x04\x12,\n(COUNT_DISTINCT_IMPLEMENTATION_UNIQ_EXACT\x10\x05\"\x90\x02\n\rJoinAlgorithm\x12\x1e\n\x1aJOIN_ALGORITHM_UNSPECIFIED\x10\x00\x12\x17\n\x13JOIN_ALGORITHM_HASH\x10\x01\x12 \n\x1cJOIN_ALGORITHM_PARALLEL_HASH\x10\x02\x12 \n\x1cJOIN_ALGORITHM_PARTIAL_MERGE\x10\x03\x12\x19\n\x15JOIN_ALGORITHM_DIRECT\x10\x04\x12\x17\n\x13JOIN_ALGORITHM_AUTO\x10\x05\x12%\n!JOIN_ALGORITHM_FULL_SORTING_MERGE\x10\x06\x12\'\n#JOIN_ALGORITHM_PREFER_PARTIAL_MERGE\x10\x07J\x04\x08R\x10SJ\x04\x08S\x10T\"\xee\x02\n\tUserQuota\x12\x42\n\x11interval_duration\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06>=1000\x12\x35\n\x07queries\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x34\n\x06\x65rrors\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x39\n\x0bresult_rows\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x37\n\tread_rows\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12<\n\x0e\x65xecution_time\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\"*\n\x11\x43onnectionManager\x12\x15\n\rconnection_id\x18\x01 \x01(\t\"\xd4\x02\n\x08UserSpec\x12\x38\n\x04name\x18\x01 \x01(\tB*\xe8\xc7\x31\x01\xf2\xc7\x31\x1a[a-zA-Z0-9_][a-zA-Z0-9_-]*\x8a\xc8\x31\x04\x31-32\x12\x1b\n\x08password\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05\x38-128\x12\x35\n\x11generate_password\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0bpermissions\x18\x03 \x03(\x0b\x32*.yandex.cloud.mdb.clickhouse.v1.Permission\x12>\n\x08settings\x18\x04 \x01(\x0b\x32,.yandex.cloud.mdb.clickhouse.v1.UserSettings\x12\x39\n\x06quotas\x18\x05 \x03(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.UserQuotaBs\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.clickhouse.v1.user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse'
  _globals['_USER'].fields_by_name['name']._loaded_options = None
  _globals['_USER'].fields_by_name['name']._serialized_options = b'\350\3071\001'
  _globals['_USER'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_USER'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _globals['_USERSETTINGS'].fields_by_name['readonly']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['readonly']._serialized_options = b'\372\3071\0030-2'
  _globals['_USERSETTINGS'].fields_by_name['insert_quorum']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['insert_quorum']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['replication_alter_partitions_sync']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['replication_alter_partitions_sync']._serialized_options = b'\372\3071\0030-2'
  _globals['_USERSETTINGS'].fields_by_name['min_count_to_compile_expression']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['min_count_to_compile_expression']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_block_size']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_block_size']._serialized_options = b'\372\3071\003>=1'
  _globals['_USERSETTINGS'].fields_by_name['min_insert_block_size_rows']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['min_insert_block_size_rows']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['min_insert_block_size_bytes']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['min_insert_block_size_bytes']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_insert_block_size']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_insert_block_size']._serialized_options = b'\372\3071\003>=1'
  _globals['_USERSETTINGS'].fields_by_name['max_partitions_per_insert_block']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_partitions_per_insert_block']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['min_bytes_to_use_direct_io']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['min_bytes_to_use_direct_io']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['merge_tree_max_rows_to_use_cache']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['merge_tree_max_rows_to_use_cache']._serialized_options = b'\372\3071\003>=1'
  _globals['_USERSETTINGS'].fields_by_name['merge_tree_max_bytes_to_use_cache']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['merge_tree_max_bytes_to_use_cache']._serialized_options = b'\372\3071\003>=1'
  _globals['_USERSETTINGS'].fields_by_name['merge_tree_min_rows_for_concurrent_read']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['merge_tree_min_rows_for_concurrent_read']._serialized_options = b'\372\3071\003>=1'
  _globals['_USERSETTINGS'].fields_by_name['merge_tree_min_bytes_for_concurrent_read']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['merge_tree_min_bytes_for_concurrent_read']._serialized_options = b'\372\3071\003>=1'
  _globals['_USERSETTINGS'].fields_by_name['max_bytes_before_external_group_by']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_bytes_before_external_group_by']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_bytes_before_external_sort']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_bytes_before_external_sort']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['group_by_two_level_threshold']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['group_by_two_level_threshold']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['group_by_two_level_threshold_bytes']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['group_by_two_level_threshold_bytes']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['priority']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['priority']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_threads']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_threads']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_insert_threads']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_insert_threads']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_memory_usage']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_memory_usage']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_memory_usage_for_user']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_memory_usage_for_user']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['memory_overcommit_ratio_denominator']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['memory_overcommit_ratio_denominator']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['memory_overcommit_ratio_denominator_for_user']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['memory_overcommit_ratio_denominator_for_user']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['memory_usage_overcommit_max_wait_microseconds']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['memory_usage_overcommit_max_wait_microseconds']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_network_bandwidth']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_network_bandwidth']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_network_bandwidth_for_user']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_network_bandwidth_for_user']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_temporary_data_on_disk_size_for_query']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_temporary_data_on_disk_size_for_query']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_temporary_data_on_disk_size_for_user']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_temporary_data_on_disk_size_for_user']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_rows_to_read']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_rows_to_read']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_bytes_to_read']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_bytes_to_read']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_rows_to_group_by']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_rows_to_group_by']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_rows_to_sort']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_rows_to_sort']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_bytes_to_sort']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_bytes_to_sort']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_result_rows']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_result_rows']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_result_bytes']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_result_bytes']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_rows_in_distinct']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_rows_in_distinct']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_bytes_in_distinct']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_bytes_in_distinct']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_rows_to_transfer']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_rows_to_transfer']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_bytes_to_transfer']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_bytes_to_transfer']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_execution_time']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_execution_time']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_rows_in_set']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_rows_in_set']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_bytes_in_set']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_bytes_in_set']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_rows_in_join']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_rows_in_join']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_bytes_in_join']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_bytes_in_join']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_columns_to_read']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_columns_to_read']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_temporary_columns']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_temporary_columns']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_temporary_non_const_columns']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_temporary_non_const_columns']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_query_size']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_query_size']._serialized_options = b'\372\3071\003>=1'
  _globals['_USERSETTINGS'].fields_by_name['max_ast_depth']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_ast_depth']._serialized_options = b'\372\3071\003>=1'
  _globals['_USERSETTINGS'].fields_by_name['max_ast_elements']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_ast_elements']._serialized_options = b'\372\3071\003>=1'
  _globals['_USERSETTINGS'].fields_by_name['max_expanded_ast_elements']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_expanded_ast_elements']._serialized_options = b'\372\3071\003>=1'
  _globals['_USERSETTINGS'].fields_by_name['max_parser_depth']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_parser_depth']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['min_execution_speed']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['min_execution_speed']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['min_execution_speed_bytes']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['min_execution_speed_bytes']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['query_cache_min_query_runs']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['query_cache_min_query_runs']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['memory_profiler_step']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['memory_profiler_step']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['memory_profiler_sample_probability']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['memory_profiler_sample_probability']._serialized_options = b'\372\3071\0030-1'
  _globals['_USERSETTINGS'].fields_by_name['max_final_threads']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_final_threads']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['max_read_buffer_size']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['max_read_buffer_size']._serialized_options = b'\372\3071\003>=1'
  _globals['_USERSETTINGS'].fields_by_name['insert_keeper_max_retries']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['insert_keeper_max_retries']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSETTINGS'].fields_by_name['compile']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['compile']._serialized_options = b'\030\001'
  _globals['_USERSETTINGS'].fields_by_name['min_count_to_compile']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['min_count_to_compile']._serialized_options = b'\030\001'
  _globals['_USERSETTINGS'].fields_by_name['async_insert_threads']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['async_insert_threads']._serialized_options = b'\030\001'
  _globals['_USERSETTINGS'].fields_by_name['async_insert_stale_timeout']._loaded_options = None
  _globals['_USERSETTINGS'].fields_by_name['async_insert_stale_timeout']._serialized_options = b'\030\001'
  _globals['_USERQUOTA'].fields_by_name['interval_duration']._loaded_options = None
  _globals['_USERQUOTA'].fields_by_name['interval_duration']._serialized_options = b'\372\3071\006>=1000'
  _globals['_USERQUOTA'].fields_by_name['queries']._loaded_options = None
  _globals['_USERQUOTA'].fields_by_name['queries']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERQUOTA'].fields_by_name['errors']._loaded_options = None
  _globals['_USERQUOTA'].fields_by_name['errors']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERQUOTA'].fields_by_name['result_rows']._loaded_options = None
  _globals['_USERQUOTA'].fields_by_name['result_rows']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERQUOTA'].fields_by_name['read_rows']._loaded_options = None
  _globals['_USERQUOTA'].fields_by_name['read_rows']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERQUOTA'].fields_by_name['execution_time']._loaded_options = None
  _globals['_USERQUOTA'].fields_by_name['execution_time']._serialized_options = b'\372\3071\003>=0'
  _globals['_USERSPEC'].fields_by_name['name']._loaded_options = None
  _globals['_USERSPEC'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\032[a-zA-Z0-9_][a-zA-Z0-9_-]*\212\3101\0041-32'
  _globals['_USERSPEC'].fields_by_name['password']._loaded_options = None
  _globals['_USERSPEC'].fields_by_name['password']._serialized_options = b'\212\3101\0058-128'
  _globals['_USER']._serialized_start=141
  _globals['_USER']._serialized_end=460
  _globals['_PERMISSION']._serialized_start=462
  _globals['_PERMISSION']._serialized_end=503
  _globals['_USERSETTINGS']._serialized_start=506
  _globals['_USERSETTINGS']._serialized_end=16043
  _globals['_USERSETTINGS_DISTRIBUTEDPRODUCTMODE']._serialized_start=12604
  _globals['_USERSETTINGS_DISTRIBUTEDPRODUCTMODE']._serialized_end=12814
  _globals['_USERSETTINGS_DISTRIBUTEDDDLOUTPUTMODE']._serialized_start=12817
  _globals['_USERSETTINGS_DISTRIBUTEDDDLOUTPUTMODE']._serialized_end=13235
  _globals['_USERSETTINGS_LOADBALANCING']._serialized_start=13238
  _globals['_USERSETTINGS_LOADBALANCING']._serialized_end=13446
  _globals['_USERSETTINGS_LOCALFILESYSTEMREADMETHOD']._serialized_start=13449
  _globals['_USERSETTINGS_LOCALFILESYSTEMREADMETHOD']._serialized_end=13734
  _globals['_USERSETTINGS_REMOTEFILESYSTEMREADMETHOD']._serialized_start=13737
  _globals['_USERSETTINGS_REMOTEFILESYSTEMREADMETHOD']._serialized_end=13898
  _globals['_USERSETTINGS_OVERFLOWMODE']._serialized_start=13900
  _globals['_USERSETTINGS_OVERFLOWMODE']._serialized_end=13995
  _globals['_USERSETTINGS_GROUPBYOVERFLOWMODE']._serialized_start=13998
  _globals['_USERSETTINGS_GROUPBYOVERFLOWMODE']._serialized_end=14159
  _globals['_USERSETTINGS_DATETIMEINPUTFORMAT']._serialized_start=14162
  _globals['_USERSETTINGS_DATETIMEINPUTFORMAT']._serialized_end=14340
  _globals['_USERSETTINGS_DATETIMEOUTPUTFORMAT']._serialized_start=14343
  _globals['_USERSETTINGS_DATETIMEOUTPUTFORMAT']._serialized_end=14519
  _globals['_USERSETTINGS_FORMATREGEXPESCAPINGRULE']._serialized_start=14522
  _globals['_USERSETTINGS_FORMATREGEXPESCAPINGRULE']._serialized_end=14823
  _globals['_USERSETTINGS_QUOTAMODE']._serialized_start=14825
  _globals['_USERSETTINGS_QUOTAMODE']._serialized_end=14938
  _globals['_USERSETTINGS_QUERYCACHENONDETERMINISTICFUNCTIONHANDLING']._serialized_start=14941
  _globals['_USERSETTINGS_QUERYCACHENONDETERMINISTICFUNCTIONHANDLING']._serialized_end=15223
  _globals['_USERSETTINGS_QUERYCACHESYSTEMTABLEHANDLING']._serialized_start=15226
  _globals['_USERSETTINGS_QUERYCACHESYSTEMTABLEHANDLING']._serialized_end=15443
  _globals['_USERSETTINGS_COUNTDISTINCTIMPLEMENTATION']._serialized_start=15446
  _globals['_USERSETTINGS_COUNTDISTINCTIMPLEMENTATION']._serialized_end=15756
  _globals['_USERSETTINGS_JOINALGORITHM']._serialized_start=15759
  _globals['_USERSETTINGS_JOINALGORITHM']._serialized_end=16031
  _globals['_USERQUOTA']._serialized_start=16046
  _globals['_USERQUOTA']._serialized_end=16412
  _globals['_CONNECTIONMANAGER']._serialized_start=16414
  _globals['_CONNECTIONMANAGER']._serialized_end=16456
  _globals['_USERSPEC']._serialized_start=16459
  _globals['_USERSPEC']._serialized_end=16799
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/metastore/v1/cluster.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/metastore/v1/cluster.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.logging.v1 import log_entry_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2
from yandex.cloud.metastore.v1 import maintenance_pb2 as yandex_dot_cloud_dot_metastore_dot_v1_dot_maintenance__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/metastore/v1/cluster.proto\x12\x19yandex.cloud.metastore.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'yandex/cloud/logging/v1/log_entry.proto\x1a+yandex/cloud/metastore/v1/maintenance.proto\x1a\x1dyandex/cloud/validation.proto\"\x9e\x08\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12>\n\x06labels\x18\x06 \x03(\x0b\x32..yandex.cloud.metastore.v1.Cluster.LabelsEntry\x12\x39\n\nmonitoring\x18\x07 \x03(\x0b\x32%.yandex.cloud.metastore.v1.Monitoring\x12\x39\n\x06health\x18\x08 \x01(\x0e\x32).yandex.cloud.metastore.v1.Cluster.Health\x12\x39\n\x06status\x18\t \x01(\x0e\x32).yandex.cloud.metastore.v1.Cluster.Status\x12\x1b\n\x13\x64\x65letion_protection\x18\x10 \x01(\x08\x12\x0f\n\x07version\x18\x11 \x01(\t\x12\x12\n\nnetwork_id\x18\x12 \x01(\t\x12\x13\n\x0b\x65ndpoint_ip\x18\x13 \x01(\t\x12@\n\x0e\x63luster_config\x18\x14 \x01(\x0b\x32(.yandex.cloud.metastore.v1.ClusterConfig\x12\x1a\n\x12service_account_id\x18\x15 \x01(\t\x12\x39\n\x07logging\x18\x16 \x01(\x0b\x32(.yandex.cloud.metastore.v1.LoggingConfig\x12\x39\n\x07network\x18\x17 \x01(\x0b\x32(.yandex.cloud.metastore.v1.NetworkConfig\x12H\n\x12maintenance_window\x18\x18 \x01(\x0b\x32,.yandex.cloud.metastore.v1.MaintenanceWindow\x12J\n\x11planned_operation\x18\x19 \x01(\x0b\x32/.yandex.cloud.metastore.v1.MaintenanceOperation\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"y\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08UPDATING\x10\x04\x12\x0c\n\x08STOPPING\x10\x05\x12\x0b\n\x07STOPPED\x10\x06\x12\x0c\n\x08STARTING\x10\x07J\x04\x08\n\x10\x10\"=\n\nMonitoring\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\"N\n\rClusterConfig\x12\x37\n\tresources\x18\x02 \x01(\x0b\x32$.yandex.cloud.metastore.v1.ResourcesJ\x04\x08\x01\x10\x02\"?\n\rNetworkConfig\x12\x12\n\nsubnet_ids\x18\x01 \x03(\t\x12\x1a\n\x12security_group_ids\x18\x02 \x03(\t\"5\n\tResources\x12(\n\x12resource_preset_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xe2\x01\n\rLoggingConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x38\n\tfolder_id\x18\x02 \x01(\tB#\xf2\xc7\x31\x1f([a-zA-Z][-a-zA-Z0-9_.]{0,63})?H\x00\x12;\n\x0clog_group_id\x18\x03 \x01(\tB#\xf2\xc7\x31\x1f([a-zA-Z][-a-zA-Z0-9_.]{0,63})?H\x00\x12:\n\tmin_level\x18\x04 \x01(\x0e\x32\'.yandex.cloud.logging.v1.LogLevel.LevelB\r\n\x0b\x64\x65stinationBh\n\x1dyandex.cloud.api.metastore.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/metastore/v1;metastoreb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.metastore.v1.cluster_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035yandex.cloud.api.metastore.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/metastore/v1;metastore'
  _globals['_CLUSTER_LABELSENTRY']._loaded_options = None
  _globals['_CLUSTER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_RESOURCES'].fields_by_name['resource_preset_id']._loaded_options = None
  _globals['_RESOURCES'].fields_by_name['resource_preset_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LOGGINGCONFIG'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LOGGINGCONFIG'].fields_by_name['folder_id']._serialized_options = b'\362\3071\037([a-zA-Z][-a-zA-Z0-9_.]{0,63})?'
  _globals['_LOGGINGCONFIG'].fields_by_name['log_group_id']._loaded_options = None
  _globals['_LOGGINGCONFIG'].fields_by_name['log_group_id']._serialized_options = b'\362\3071\037([a-zA-Z][-a-zA-Z0-9_.]{0,63})?'
  _globals['_CLUSTER']._serialized_start=221
  _globals['_CLUSTER']._serialized_end=1275
  _globals['_CLUSTER_LABELSENTRY']._serialized_start=1036
  _globals['_CLUSTER_LABELSENTRY']._serialized_end=1081
  _globals['_CLUSTER_HEALTH']._serialized_start=1083
  _globals['_CLUSTER_HEALTH']._serialized_end=1146
  _globals['_CLUSTER_STATUS']._serialized_start=1148
  _globals['_CLUSTER_STATUS']._serialized_end=1269
  _globals['_MONITORING']._serialized_start=1277
  _globals['_MONITORING']._serialized_end=1338
  _globals['_CLUSTERCONFIG']._serialized_start=1340
  _globals['_CLUSTERCONFIG']._serialized_end=1418
  _globals['_NETWORKCONFIG']._serialized_start=1420
  _globals['_NETWORKCONFIG']._serialized_end=1483
  _globals['_RESOURCES']._serialized_start=1485
  _globals['_RESOURCES']._serialized_end=1538
  _globals['_LOGGINGCONFIG']._serialized_start=1541
  _globals['_LOGGINGCONFIG']._serialized_end=1767
# @@protoc_insertion_point(module_scope)
